@@ -72,8 +72,8 @@ public abstract class StreamScanner
     /**
      * Character that allows quick check of whether a char can potentially
      * be some kind of markup, WRT input stream processing;
-     * has to contain linefeeds, &, < and > (">" only matters when
-     * quoting text, as part of "]]>")
+     * has to contain linefeeds, {@code &}, {@code <} and {@code >} (note: {@code >} only matters when
+     * quoting text, as part of {@code ]]>})
      */
     protected final static char CHAR_FIRST_PURE_TEXT = (char) ('>' + 1);
 
@@ -282,6 +282,13 @@ public abstract class StreamScanner
      */
     protected boolean mNormalizeLFs;
 
+    /**
+     * Flag that indicates whether all escaped chars are accepted in XML 1.0.
+     *
+     * @since 5.2
+     */
+    protected boolean mAllowXml11EscapedCharsInXml10;
+
     /*
     ///////////////////////////////////////////////////////////////////////
     // Buffer(s) for local name(s) and text content
@@ -385,6 +392,8 @@ public abstract class StreamScanner
         mCfgNsEnabled = (cf & CFG_NAMESPACE_AWARE) != 0;
         mCfgReplaceEntities = (cf & CFG_REPLACE_ENTITY_REFS) != 0;
 
+        mAllowXml11EscapedCharsInXml10 = mConfig.willAllowXml11EscapedCharsInXml10();
+
         mNormalizeLFs = mConfig.willNormalizeLFs();
         mInputBuffer = null;
         mInputPtr = mInputEnd = 0;
@@ -398,6 +407,13 @@ public abstract class StreamScanner
         }
     }
 
+    /**
+     * @since 5.2
+     */
+    public ReaderConfig getConfig() {
+        return mConfig;
+    }
+
     /*
     ///////////////////////////////////////////////////////////////////////
     // Package API
@@ -2106,7 +2122,7 @@ public abstract class StreamScanner
      * NOTE: returned String is not canonicalized, on assumption that
      * external ids may be longish, and are not shared all that often, as
      * they are generally just used for resolving paths, if anything.
-     *<br />
+     *<br>
      * Also note that this method is not heavily optimized, as it's not
      * likely to be a bottleneck for parsing.
      */
@@ -2167,7 +2183,7 @@ public abstract class StreamScanner
      * NOTE: returned String is not canonicalized, on assumption that
      * external ids may be longish, and are not shared all that often, as
      * they are generally just used for resolving paths, if anything.
-     *<br />
+     *<br>
      * Also note that this method is not heavily optimized, as it's not
      * likely to be a bottleneck for parsing.
      */
@@ -2395,8 +2411,8 @@ public abstract class StreamScanner
                 throwParseError("Invalid character reference: null character not allowed in XML content.");
             }
             // XML 1.1 allows most other chars; 1.0 does not:
-            if (!mXml11 &&
-                (value != 0x9 && value != 0xA && value != 0xD)) {
+            if (!mXml11 && !mAllowXml11EscapedCharsInXml10
+                && (value != 0x9 && value != 0xA && value != 0xD)) {
                 reportIllegalChar(value);
             }
         }
